@@ -24,4 +24,4 @@
 #define QT_FEATURE_testlib 1
 #define QT_FEATURE_widgets 1
 #define QT_FEATURE_xml 1
-#define QT_FEATURE_zstd -1
+#define QT_FEATURE_zstd 1
